package foo.bar.tests.dmo._meta.impl;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;
import com.goldencode.p2j.persist.*;
import com.goldencode.p2j.util.*;
import foo.bar.tests.dmo._meta.*;

/**
 * Data Model Object corresponding with table <code>_meta.meta_index_field</code> (previously
 * <code>_meta._index-field</code>).
 */
@LegacyTable(name = "_index-field", table = "meta_index_field")
@LegacyIndexes(
{
   @LegacyIndex(name = "_index/number", converted = "meta_index_field_index_number", primary = true, unique = true, components = 
   {
      @LegacyIndexComponent(fieldName = "_index-recid"),
      @LegacyIndexComponent(fieldName = "_index-seq")
   }),
   @LegacyIndex(name = "_field", converted = "meta_index_field_field", components = 
   {
      @LegacyIndexComponent(fieldName = "_field-recid")
   })
})
public class MetaIndexFieldImpl
implements Serializable,
           Persistable,
           MetaIndexField
{
   /** Surrogate primary key */
   private Long id = null;

   /** Index-recid */
   @LegacyField(fieldId = 1, name = "_index-recid", format = ">>>>>>>9", initial = "?", label = "Index-recid", mandatory = true)
   private final integer indexRecid;

   /** Index-Seq */
   @LegacyField(fieldId = 2, name = "_index-seq", format = "->>9", initial = "?", label = "Index-Seq", mandatory = true)
   private final integer indexSeq;

   /** Field-recid */
   @LegacyField(fieldId = 3, name = "_field-recid", format = ">>>>>>>9", initial = "?", label = "Field-recid", mandatory = true)
   private final integer fieldRecid;

   /** Ascending */
   @LegacyField(fieldId = 4, name = "_ascending", format = "yes/no", initial = "true", label = "Ascending", mandatory = true)
   private final logical ascending;

   /** Abbreviate */
   @LegacyField(fieldId = 5, name = "_abbreviate", format = "yes/no", initial = "false", label = "Abbreviate", mandatory = true)
   private final logical abbreviate;

   /** Unsorted */
   @LegacyField(fieldId = 6, name = "_unsorted", format = "yes/no", initial = "false", label = "Unsorted", mandatory = true)
   private final logical unsorted;

   /** User-Misc */
   @LegacyField(fieldId = 11, name = "_user-misc", format = "x(10)", initial = "?", label = "User-Misc")
   private final character userMisc;

   /** Data member */
   @LegacyField(fieldId = 12, name = "_last-modified", format = "99/99/9999 HH:MM:SS.SSS+HH:MM", initial = "?")
   private final datetimetz lastModified;

   /** Data member */
   @LegacyField(fieldId = 13, name = "_mod-sequence", format = ">>>>>>9", initial = "?")
   private final integer modSequence;

   /** Collation */
   @LegacyField(fieldId = 14, name = "_collation", format = "x(19)", label = "Collation")
   private final character collation;

   /** Data member */
   @LegacyField(fieldId = 15, name = "_coll-strength", format = ">>>>>>9", initial = "0")
   private final integer collStrength;

   /** KeyValue-expr */
   @LegacyField(fieldId = 16, name = "_keyvalue-expr", format = "x(32)", label = "KeyValue-expr", caseSensitive = true)
   private final character keyvalueExpr;

   /**
    * List of composite properties; 8 elements of type {@link MetaIndexFieldImpl.Composite8
    * Composite8}
    */
   private List<Composite8> composite8 = new ArrayList<>(8);

   /**
    * Default constructor.
    */
   public MetaIndexFieldImpl()
   {
      indexRecid = new integer();
      indexSeq = new integer();
      fieldRecid = new integer();
      ascending = new logical(true);
      abbreviate = new logical(false);
      unsorted = new logical(false);
      userMisc = new character("?");
      lastModified = new datetimetz();
      modSequence = new integer();
      collation = new character("");
      collStrength = new integer(0);
      keyvalueExpr = new character("", true);
      
      // Populate Composite8 list.
      for (int i = 0; i < 8; i++)
      {
         composite8.add(new Composite8());
      }
   }

   /**
    * Make a deep copy of the current DMO instance and return it.
    * 
    * @return  A new instance of this class whose data is identical to that of this instance.
    */
   public Undoable deepCopy()
   {
      Undoable copy = new MetaIndexFieldImpl();
      copy.assign(this);
      return copy;
   }

   /**
    * Modify the contained data of the instance to copy the instance data from the given, backup
    * instance.
    * 
    * @param   old
    *          The backup instance from which to copy data.
    */
   public void assign(Undoable old)
   {
      MetaIndexFieldImpl from = (MetaIndexFieldImpl) old;
      setId(from.id);
      setIndexRecid(from.indexRecid);
      setIndexSeq(from.indexSeq);
      setFieldRecid(from.fieldRecid);
      setAscending(from.ascending);
      setAbbreviate(from.abbreviate);
      setUnsorted(from.unsorted);
      setUserMisc(from.userMisc);
      setLastModified(from.lastModified);
      setModSequence(from.modSequence);
      setCollation(from.collation);
      setCollStrength(from.collStrength);
      setKeyvalueExpr(from.keyvalueExpr);
      
      // Assign Composite8 properties.
      for (int i = 0; i < 8; i++)
      {
         setIfMisc1(i, from.composite8.get(i).ifMisc1);
         setIfMisc2(i, from.composite8.get(i).ifMisc2);
         setIfRes1(i, from.composite8.get(i).ifRes1);
         setIfRes2(i, from.composite8.get(i).ifRes2);
      }
   }

   /**
    * Getter: Surrogate primary key
    * 
    * @return  Primary key
    */
   public Long getId()
   {
      return id;
   }

   /**
    * Setter: Surrogate primary key
    * 
    * @param   id
    *          Primary key
    */
   public void setId(Long id)
   {
      this.id = id;
   }

   /**
    * Getter: Index-recid
    * 
    * @return  Index-recid
    */
   public integer getIndexRecid()
   {
      return (new integer(indexRecid));
   }

   /**
    * Setter: Index-recid
    * 
    * @param   indexRecid
    *          Index-recid
    */
   public void setIndexRecid(NumberType indexRecid)
   {
      this.indexRecid.assign(indexRecid, true);
   }

   /**
    * Getter: Index-Seq
    * 
    * @return  Index-Seq
    */
   public integer getIndexSeq()
   {
      return (new integer(indexSeq));
   }

   /**
    * Setter: Index-Seq
    * 
    * @param   indexSeq
    *          Index-Seq
    */
   public void setIndexSeq(NumberType indexSeq)
   {
      this.indexSeq.assign(indexSeq, true);
   }

   /**
    * Getter: Field-recid
    * 
    * @return  Field-recid
    */
   public integer getFieldRecid()
   {
      return (new integer(fieldRecid));
   }

   /**
    * Setter: Field-recid
    * 
    * @param   fieldRecid
    *          Field-recid
    */
   public void setFieldRecid(NumberType fieldRecid)
   {
      this.fieldRecid.assign(fieldRecid, true);
   }

   /**
    * Getter: Ascending
    * 
    * @return  Ascending
    */
   public logical isAscending()
   {
      return (new logical(ascending));
   }

   /**
    * Setter: Ascending
    * 
    * @param   ascending
    *          Ascending
    */
   public void setAscending(logical ascending)
   {
      this.ascending.assign(ascending, true);
   }

   /**
    * Getter: Abbreviate
    * 
    * @return  Abbreviate
    */
   public logical isAbbreviate()
   {
      return (new logical(abbreviate));
   }

   /**
    * Setter: Abbreviate
    * 
    * @param   abbreviate
    *          Abbreviate
    */
   public void setAbbreviate(logical abbreviate)
   {
      this.abbreviate.assign(abbreviate, true);
   }

   /**
    * Getter: Unsorted
    * 
    * @return  Unsorted
    */
   public logical isUnsorted()
   {
      return (new logical(unsorted));
   }

   /**
    * Setter: Unsorted
    * 
    * @param   unsorted
    *          Unsorted
    */
   public void setUnsorted(logical unsorted)
   {
      this.unsorted.assign(unsorted, true);
   }

   /**
    * Indexed Getter: ifMisc1
    * 
    * @param   index
    *          Index of element (where <code>0 &lt;= <em>index</em> &lt; 8</code>).
    * 
    * @return  ifMisc1
    */
   public integer getIfMisc1(int index)
   {
      return composite8.get(index).getIfMisc1();
   }

   /**
    * Indexed Setter: ifMisc1
    * 
    * @param   index
    *          Index of element (where <code>0 &lt;= <em>index</em> &lt; 8</code>).
    * @param   element
    *          ifMisc1
    */
   public void setIfMisc1(int index, NumberType element)
   {
      composite8.get(index).setIfMisc1(element);
   }

   /**
    * Indexed Getter: ifMisc2
    * 
    * @param   index
    *          Index of element (where <code>0 &lt;= <em>index</em> &lt; 8</code>).
    * 
    * @return  ifMisc2
    */
   public character getIfMisc2(int index)
   {
      return composite8.get(index).getIfMisc2();
   }

   /**
    * Indexed Setter: ifMisc2
    * 
    * @param   index
    *          Index of element (where <code>0 &lt;= <em>index</em> &lt; 8</code>).
    * @param   element
    *          ifMisc2
    */
   public void setIfMisc2(int index, Text element)
   {
      composite8.get(index).setIfMisc2(element);
   }

   /**
    * Indexed Getter: ifRes1
    * 
    * @param   index
    *          Index of element (where <code>0 &lt;= <em>index</em> &lt; 8</code>).
    * 
    * @return  ifRes1
    */
   public integer getIfRes1(int index)
   {
      return composite8.get(index).getIfRes1();
   }

   /**
    * Indexed Setter: ifRes1
    * 
    * @param   index
    *          Index of element (where <code>0 &lt;= <em>index</em> &lt; 8</code>).
    * @param   element
    *          ifRes1
    */
   public void setIfRes1(int index, NumberType element)
   {
      composite8.get(index).setIfRes1(element);
   }

   /**
    * Indexed Getter: ifRes2
    * 
    * @param   index
    *          Index of element (where <code>0 &lt;= <em>index</em> &lt; 8</code>).
    * 
    * @return  ifRes2
    */
   public character getIfRes2(int index)
   {
      return composite8.get(index).getIfRes2();
   }

   /**
    * Indexed Setter: ifRes2
    * 
    * @param   index
    *          Index of element (where <code>0 &lt;= <em>index</em> &lt; 8</code>).
    * @param   element
    *          ifRes2
    */
   public void setIfRes2(int index, Text element)
   {
      composite8.get(index).setIfRes2(element);
   }

   /**
    * Getter: User-Misc
    * 
    * @return  User-Misc
    */
   public character getUserMisc()
   {
      return (new character(userMisc));
   }

   /**
    * Setter: User-Misc
    * 
    * @param   userMisc
    *          User-Misc
    */
   public void setUserMisc(Text userMisc)
   {
      this.userMisc.assign(userMisc, true);
   }

   /**
    * Getter: lastModified
    * 
    * @return  lastModified
    */
   public datetimetz getLastModified()
   {
      return (new datetimetz(lastModified));
   }

   /**
    * Setter: lastModified
    * 
    * @param   lastModified
    *          lastModified
    */
   public void setLastModified(date lastModified)
   {
      this.lastModified.assign(lastModified, true);
   }

   /**
    * Getter: modSequence
    * 
    * @return  modSequence
    */
   public integer getModSequence()
   {
      return (new integer(modSequence));
   }

   /**
    * Setter: modSequence
    * 
    * @param   modSequence
    *          modSequence
    */
   public void setModSequence(NumberType modSequence)
   {
      this.modSequence.assign(modSequence, true);
   }

   /**
    * Getter: Collation
    * 
    * @return  Collation
    */
   public character getCollation()
   {
      return (new character(collation));
   }

   /**
    * Setter: Collation
    * 
    * @param   collation
    *          Collation
    */
   public void setCollation(Text collation)
   {
      this.collation.assign(collation, true);
   }

   /**
    * Getter: collStrength
    * 
    * @return  collStrength
    */
   public integer getCollStrength()
   {
      return (new integer(collStrength));
   }

   /**
    * Setter: collStrength
    * 
    * @param   collStrength
    *          collStrength
    */
   public void setCollStrength(NumberType collStrength)
   {
      this.collStrength.assign(collStrength, true);
   }

   /**
    * Getter: KeyValue-expr
    * 
    * @return  KeyValue-expr
    */
   public character getKeyvalueExpr()
   {
      return (new character(keyvalueExpr));
   }

   /**
    * Setter: KeyValue-expr
    * 
    * @param   keyvalueExpr
    *          KeyValue-expr
    */
   public void setKeyvalueExpr(Text keyvalueExpr)
   {
      this.keyvalueExpr.assign(keyvalueExpr, true);
   }

   /**
    * Inner class which composites properties of like extent. All properties migrated from the
    * legacy table <code>_meta._index-field</code> of extent 8 are data members of this class.
    */
   static class Composite8
   implements Serializable
   {
      /** Data member */
      @LegacyField(fieldId = 7, name = "_if-misc1", format = ">>>9", initial = "?", extent = 8)
      private final integer ifMisc1;

      /** Data member */
      @LegacyField(fieldId = 8, name = "_if-misc2", format = "x(12)", initial = "?", extent = 8)
      private final character ifMisc2;

      /** Data member */
      @LegacyField(fieldId = 9, name = "_if-res1", format = ">>>9", initial = "?", extent = 8)
      private final integer ifRes1;

      /** Data member */
      @LegacyField(fieldId = 10, name = "_if-res2", format = "x(12)", initial = "?", extent = 8)
      private final character ifRes2;

      /**
       * Default constructor.
       */
      public Composite8()
      {
         ifMisc1 = new integer();
         ifMisc2 = new character("?");
         ifRes1 = new integer();
         ifRes2 = new character("?");
      }

      /**
       * Getter: ifMisc1
       * 
       * @return  ifMisc1
       */
      public integer getIfMisc1()
      {
         return (new integer(ifMisc1));
      }

      /**
       * Setter: ifMisc1
       * 
       * @param   ifMisc1
       *          ifMisc1
       */
      public void setIfMisc1(NumberType ifMisc1)
      {
         this.ifMisc1.assign(ifMisc1, true);
      }

      /**
       * Getter: ifMisc2
       * 
       * @return  ifMisc2
       */
      public character getIfMisc2()
      {
         return (new character(ifMisc2));
      }

      /**
       * Setter: ifMisc2
       * 
       * @param   ifMisc2
       *          ifMisc2
       */
      public void setIfMisc2(Text ifMisc2)
      {
         this.ifMisc2.assign(ifMisc2, true);
      }

      /**
       * Getter: ifRes1
       * 
       * @return  ifRes1
       */
      public integer getIfRes1()
      {
         return (new integer(ifRes1));
      }

      /**
       * Setter: ifRes1
       * 
       * @param   ifRes1
       *          ifRes1
       */
      public void setIfRes1(NumberType ifRes1)
      {
         this.ifRes1.assign(ifRes1, true);
      }

      /**
       * Getter: ifRes2
       * 
       * @return  ifRes2
       */
      public character getIfRes2()
      {
         return (new character(ifRes2));
      }

      /**
       * Setter: ifRes2
       * 
       * @param   ifRes2
       *          ifRes2
       */
      public void setIfRes2(Text ifRes2)
      {
         this.ifRes2.assign(ifRes2, true);
      }
   }
}
